==> libgtk-java-2.5.3.tar.bz2: libgtk-java-2.5.3/src/java/org/gnu/gdk/EventCrossing.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;
import org.gnu.glib.Boxed;
import org.gnu.glib.Handle;
/**
 *
 */
public class EventCrossing extends Boxed 
{
	public EventCrossing(Handle handle) {
		this.handle = handle;
	}
	
    /****************************************
     * BEGINNING OF GENERATED CODE
     ****************************************/
    native static final protected int getType (Handle obj);
    native static final protected Handle getWindow (Handle obj);
    native static final protected boolean getSendEvent (Handle obj);
    native static final protected Handle getSubwindow (Handle obj);
    native static final protected int getTime (Handle obj);
    native static final protected double getX (Handle obj);
    native static final protected double getY (Handle obj);
    native static final protected double getXRoot (Handle obj);
    native static final protected double getYRoot (Handle obj);
    native static final protected int getMode (Handle obj);
    native static final protected int getDetail (Handle obj);
    native static final protected boolean getFocus (Handle obj);
    native static final protected int getState (Handle obj);
    /****************************************
     * END OF GENERATED CODE
     ****************************************/
}

==> libgtk-java-2.7.0.tar.bz2: libgtk-java-2.7.0/src/java/org/gnu/gdk/EventCrossing.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;

import org.gnu.javagnome.Handle;

/**
 *
 */
public class EventCrossing extends Event
{
    /**
     * Promotion constructor. Construct the specific event object by
     * promoting (sharing the <tt>Handle</tt> object of) the base
     * <tt>Event</tt>.
     */
    public EventCrossing( Event evt ) {
        // We share the handle with both instances.  This avoids
        // copying the event (via the constructor ( super( evt ) ).
        // It is more of a "promotion" constructor.
        super( evt.getHandle() );
    }

    public EventCrossing(Handle handle) {
        super(handle);
    }
	
    public Window getWindow() {
        return Window.getWindowFromHandle(getWindow(getHandle()));
    }
    
    native static final protected Handle getWindow (Handle obj);
    native static final protected boolean getSendEvent (Handle obj);
    native static final protected Handle getSubwindow (Handle obj);
    native static final protected int getTime (Handle obj);
    native static final protected double getX (Handle obj);
    native static final protected double getY (Handle obj);
    native static final protected double getXRoot (Handle obj);
    native static final protected double getYRoot (Handle obj);
    native static final protected int getMode (Handle obj);
    native static final protected int getDetail (Handle obj);
    native static final protected boolean getFocus (Handle obj);
    native static final protected int getState (Handle obj);
}
